@@ -9,7 +9,7 @@ from edps import (
 from .ifs_datasources import *
 from .sphere_rules import TEN_DAYS, TWELVE_DAYS
 from .sphere_task_functions import (
-    is_YJH, which_disperser, distortion_mandatory, distortion_optional,
+    is_YJH, which_disperser, distortion_mandatory, distortion_optional, set_skybackground_parameters
 )
 
 """
@@ -57,6 +57,7 @@ def process_ifs_dark_background():
     task_ifs_sky_bg = (task("ifs_sky_background")
                        .with_recipe("sph_ifs_cal_background")
                        .with_main_input(ifs_raw_sky_bg)
+                       .with_job_processing(set_skybackground_parameters)
                        .with_meta_targets([qc0])
                        .build())
 
